# Pyx3270 — Automação para Mainframes com Python

<img src="https://raw.githubusercontent.com/matheusLPolidoro/pyx3270/master/docs/assets/logo.svg" width="180px">


![PyPI - Version](https://img.shields.io/pypi/v/pyx3270)
![Python](https://img.shields.io/badge/language-Python-blue?logo=python)
![Cobertura de Testes](https://img.shields.io/badge/cobertura-97%25-brightgreen?logo=pytest)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/fastapi.svg?color=%2334D058)](https://pypi.org/project/fastapi)

Pyx3270 é uma biblioteca Python voltada para interação com emuladores de [terminais 3270](https://www.ibm.com/docs/api/v1/content/zosbasics%2Fcom.ibm.zos.znetwork%2Fznetwork_261.htm?parsebody=true&lang=en) usados em sistemas mainframe.Com ela, você pode gravar sessões, reproduzi-las offline e automatizar processos complexos com simplicidade e controle.

## Sobre o emulador:

### [x3270 Wiki](https://x3270.miraheze.org/wiki/Main_Page)
Esta Wiki contém documentação para a família x3270 de emuladores de terminais IBM 3270. 

### [Licença](https://x3270.miraheze.org/wiki/X3270_license)
Aqui está o aviso oficial de direitos autorais para x3270, c3270, wc3270, s3270, tcl3270 e pr3287.

## Explore os principais tópicos da biblioteca:

## [O que é o Pyx3270?](https://github.com/matheusLPolidoro/pyx3270/blob/master/docs/sobre.md)  
Entenda o contexto dos sistemas mainframe, o que são sessões 3270 e como o Pyx3270 resolve desafios comuns de automação.

## [Primeiros passos](https://github.com/matheusLPolidoro/pyx3270/blob/master/docs/primeiros_passos.md)  
Aprenda como instalar, configurar e começar a usar a biblioteca. Veja os principais módulos: Automação, Gravação e Reprodução.

## [Tutorial](https://github.com/matheusLPolidoro/pyx3270/blob/master/docs/tutorial.md)  
Siga um passo a passo prático para automatizar uma sessão real, gravar interações e reproduzi-las offline.

## [Comandos Nativos](https://github.com/matheusLPolidoro/pyx3270/blob/master/docs/comandos.md)  
Explore os comandos disponíveis para interagir com o terminal 3270 e como usá-los em scripts Python.

## [Alterações](https://github.com/matheusLPolidoro/pyx3270/blob/master/docs/changelog.md)  
Acompanhe as atualizações da biblioteca, correções de bugs e novas funcionalidades por versão.

## [Estrutura](https://github.com/matheusLPolidoro/pyx3270/blob/master/docs/estrutura.md)  
Explore a estrutura do projeto.

## [Contribuindo](https://github.com/matheusLPolidoro/pyx3270/blob/master/docs/contribuindo.md)  
Veja como colaborar com o projeto, enviar melhorias e participar da comunidade Pyx3270.
